tsseg package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   tsseg.algorithms
   tsseg.metrics

Module contents
---------------

.. automodule:: tsseg
   :members:
   :show-inheritance:
   :undoc-members:
